@@ -8,10 +8,8 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Reindeer::Builder;
-BEGIN {
-  $Reindeer::Builder::AUTHORITY = 'cpan:RSRCHBOY';
-}
-$Reindeer::Builder::VERSION = '0.017';
+our $AUTHORITY = 'cpan:RSRCHBOY';
+$Reindeer::Builder::VERSION = '0.018';
 # ABSTRACT: Easily build a new 'Reindeer' style class
 
 use strict;
@@ -83,13 +81,15 @@ __END__
 
 =for :stopwords Chris Weyl metaclass
 
+=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
+
 =head1 NAME
 
 Reindeer::Builder - Easily build a new 'Reindeer' style class
 
 =head1 VERSION
 
-This document describes version 0.017 of Reindeer::Builder - released March 03, 2014 as part of Reindeer.
+This document describes version 0.018 of Reindeer::Builder - released March 28, 2015 as part of Reindeer.
 
 =head1 SYNOPSIS
 
@@ -168,8 +168,8 @@ L<L<Reindeer>, L<Moose::Exporter>.|L<Reindeer>, L<Moose::Exporter>.>
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/RsrchBoy/reindeer>
-and may be cloned from L<git://github.com/RsrchBoy/reindeer.git>
+The development version is on github at L<http://https://github.com/RsrchBoy/reindeer>
+and may be cloned from L<git://https://github.com/RsrchBoy/reindeer.git>
 
 =head1 BUGS
 
@@ -184,6 +184,25 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head2 I'm a material boy in a material world
+
+=begin html
+
+<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
+<a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
+<a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Freindeer&title=RsrchBoy's%20CPAN%20Reindeer&tags=%22RsrchBoy's%20Reindeer%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
+
+=end html
+
+Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
+rather B<it is simply a very pleasant surprise>. I largely create and release
+works like this because I need them or I find it enjoyable; however, don't let
+that stop you if you feel like it ;)
+
+L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Freindeer&title=RsrchBoy's%20CPAN%20Reindeer&tags=%22RsrchBoy's%20Reindeer%20in%20the%20CPAN%22>,
+L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
+L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2011 by Chris Weyl.
